---
title: <span class="badge object-type-enum"></span> BarGaugeDisplayMode
---
# <span class="badge object-type-enum"></span> BarGaugeDisplayMode

Enum expressing the possible display modes

for the bar gauge component of Grafana UI

## Definition

```python
class BarGaugeDisplayMode(enum.StrEnum):
    """
    Enum expressing the possible display modes
    for the bar gauge component of Grafana UI
    """

    BASIC = "basic"
    LCD = "lcd"
    GRADIENT = "gradient"
```
